//
//
//
//  digilent video decoder expansion board
//
//


#include <xbasic_types.h>
#include <xparameters.h>
#include <xi2c_l.h>
#include <uart.h>
#include <xio.h>


#define GPO_REG_OFFSET 0x124
//#define DECODER_ADDR 0x21  //Read: 0x43, Write: 0x42
#define DECODER_ADDR 0x20 //Read: 0x41, Write: 0x40
#define SEND_CNT 3
#define RECV_CNT 3
#define GPO_RESETS_OFF 1
#define GPO_RESET_IIC 3
#define GPO_RESET_DECODER 0

struct VideoModule {
  Xuint8 addr;
  Xuint8 config_val;
  Xuint8 actual_val;
};


#define DECODER_SVID_CONFIG_CNT 17
struct VideoModule decoder_svid[] = { 
  { 0x00, 0x06, 0 },
  { 0x15, 0x00, 0 },
  { 0x27, 0x58, 0 },
  { 0x3a, 0x12, 0 },
  { 0x50, 0x04, 0 },
  { 0x0e, 0x80, 0 },
  { 0x50, 0x20, 0 },
  { 0x52, 0x18, 0 }, 
  { 0x58, 0xed, 0 },
  { 0x77, 0xc5, 0 },
  { 0x7c, 0x93, 0 },
  { 0x7d, 0x00, 0 },
  { 0xd0, 0x48, 0 },
  { 0xd5, 0xa0, 0 },
  { 0xd7, 0xea, 0 },
  { 0xe4, 0x3e, 0 },
  { 0xea, 0x0f, 0 }, 
  { 0x0e, 0x00, 0 } };

#define DECODER_COMP_CONFIG_CNT 18
struct VideoModule decoder_comp[] = { 
  { 0x00, 0x04, 0 },
  { 0x15, 0x00, 0 },
  { 0x17, 0x41, 0 },
  { 0x27, 0x58, 0 },
  { 0x3a, 0x16, 0 }, 
  { 0x50, 0x04, 0 },
  { 0x0e, 0x80, 0 },
  { 0x50, 0x20, 0 },
  { 0x52, 0x18, 0 }, 
  { 0x58, 0xed, 0 },
  { 0x77, 0xc5, 0 },
  { 0x7c, 0x93, 0 },
  { 0x7d, 0x00, 0 },
  { 0xd0, 0x48, 0 },
  { 0xd5, 0xa0, 0 },
  { 0xd7, 0xea, 0 },
  { 0xe4, 0x3e, 0 },
  { 0xea, 0x0f, 0 }, 
  { 0x0e, 0x00, 0 } };


#define DECODER_CMPNT_CONFIG_CNT 13
struct VideoModule decoder_cmpnt[] = { 
  { 0x00, 0x0a, 0 },
  { 0x27, 0xd8, 0 },
  { 0x50, 0x04, 0 },
  { 0x0e, 0x80, 0 },
  { 0x52, 0x18, 0 }, 
  { 0x58, 0xed, 0 },
  { 0x77, 0xc5, 0 },
  { 0x7c, 0x93, 0 },
  { 0x7d, 0x00, 0 },
  { 0xd0, 0x48, 0 },
  { 0xd5, 0xa0, 0 },
  { 0xe4, 0x3e, 0 },
  { 0x0e, 0x00, 0 } };

//
// funtion prototypes
//

void configDecoder(struct VideoModule *decoder, int config_cnt );
void Reset_xup_decoder(void);
void main_memu(void);
unsigned char get_hex_byte();
void edit_i2c_reg(void);

int main() {
  Xuint8 start_addr = 0;
  Xuint8 send_data[SEND_CNT] = {0};
  Xuint32 send_cnt;
  Xuint8 recv_data[RECV_CNT] = {0};
  Xuint32 recv_cnt;
  Xuint8 i;
  int wait_delay = 50000000;

    uartInit(XPAR_RS232_UART_1_BASEADDR);

    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESETS_OFF);// deassert reset to vid decoder
    recv_cnt = 0;
	print("\r\nXUP-V2Pro Video Decoder Expansion Board Video Pass Through Test  ");
    print("\r\nDetecting Video Decoder...\t");
    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESET_IIC);
    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESETS_OFF);
    recv_cnt = XI2c_RSRecv(XPAR_I2C_BASEADDR, DECODER_ADDR, start_addr, 
			   recv_data, 1);
    if( recv_cnt != 1 )
      print("No device detected!\r\n");
    else {
	  configDecoder(decoder_comp, DECODER_COMP_CONFIG_CNT);
      print("Decoder detected! Configuring for composite video -  default.\r\n");
	  main_memu();
	  }
  
  print("\r\nTest Complete!\r\n\r\n");
} // end main()

void main_memu(void)
{
  unsigned char x, s;
   s = 0;

  do {

    print("\r\nMode Selection Menu ");
    print("\r\n----------------------------------------------------------\r\n");
    print("1 - Program Composite Video Input Mode.\r\n");
    print("2 - Program S - Video Input Mode.\r\n");
    print("3 - Program Component Video Input Mode.\r\n");
    print("4 - Edit Setting Mode\r\n");
    //print("5 - \r\n");
	//print("6 - \r\n");
    print("q - Quit\r\n");

    do {
      s = uartRead();
    } while((s < '1' || s > '4')  && s != 'q');

    switch(s) {
    case '1':
	  Reset_xup_decoder();
      configDecoder(decoder_comp, DECODER_COMP_CONFIG_CNT);
      break;
    case '2':
      Reset_xup_decoder();
	  configDecoder(decoder_svid, DECODER_SVID_CONFIG_CNT);
      break;
    case '3':
	 Reset_xup_decoder();           
     configDecoder(decoder_cmpnt, DECODER_CMPNT_CONFIG_CNT);
      break;
    case '4':
      edit_i2c_reg();
      break;
    }

  } while( s != 'q' );

  print("\r\nGoodbye.\r\n");

  return;
} // end main_menu


void configDecoder(struct VideoModule *decoder, int config_cnt ) 
{
  Xuint16 send_cnt, i;
  Xuint8 send_data[2] = {0};
  Xuint8 success = 1;
  send_cnt = 2;
  print("  Configuring Decoder...\t");
  for( i = 0; i < config_cnt; i++ )
   {

    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESET_IIC);
    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESETS_OFF);
    send_data[0] = decoder[i].addr;

    send_data[1] = decoder[i].config_val;

    send_cnt = XI2c_Send(XPAR_I2C_BASEADDR, DECODER_ADDR, send_data, 2);

    if( send_cnt != 2 ) 
	 {
      xil_printf("Error writing to address %02x\r\n", decoder[i].addr);
      success = 0;
      break;
     }
   }

  if( success )
    print("SUCCESS!\r\n");

} // end configDecoder()

void Reset_xup_decoder(void)
{
int send_cnt = 0;
int wait_delay = 500000;
    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESET_DECODER);  // reset  to vid decoder
	while(wait_delay)
   {
    wait_delay = wait_delay -1;
	}
    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESETS_OFF);  // set resets de - asserted
	wait_delay = 5000000;
   while(wait_delay)
   {
    wait_delay = wait_delay -1;
	}
   return;
}  // end Reset_xup_decoder

unsigned char get_hex_byte()
{
  unsigned char s ,x, pass;
  pass = 0;
  s = 0;
  x = 0;
    while( s != 13)
    {
    s = uartRead();
	xil_printf("%c",s); //echo back 
	if((s < '0' ||  s >'f')  && s != 13){
	  print(" invalid entry start over \n\r");
	  x = 0;
	  }
	if( s == 13){
	  break;
	  }
	 else{
	  if(pass != 0){
	   x= x*16;
	   }
	  if(s > 47 && s < 58){
	  s = ( s - '0');
	  x = x + s;
	  }
	  else if( s == 'a'){
	   x = x + 10;
	   }
	   else if( s == 'b'){
	   x = x + 11;
	   }
	   else if( s == 'c'){
	   x = x + 12;
	   }
	   else if( s == 'd'){
	   x = x + 13;
	   }
	   else if( s == 'e'){
	   x = x + 14;
	   }
	   else if( s == 'f'){
	   x = x + 15;
	   }
      pass++;
	  }
	}

	return x;
}
void edit_i2c_reg(void)
{
  Xuint8 send_data[2] = {0};
  int send_cnt = 0;
  char s = 0;
  
    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESET_IIC);
    XI2c_mWriteReg(XPAR_I2C_BASEADDR, GPO_REG_OFFSET, GPO_RESETS_OFF);
	print("\r\nEdit I2C Register Settings Mode.\r\n");
   do {
		print("\r\nEnter I2C Hex Register Address  ");
		send_data[0] = get_hex_byte();
		print("\r\nEnter I2C Hex Register Data     ");
		send_data[1] = get_hex_byte();
		send_cnt = XI2c_Send(XPAR_I2C_BASEADDR, DECODER_ADDR, send_data, 2);
	    if( send_cnt != 2 ) 
		  {
	      xil_printf("Error writing to address %02x\r\n", send_data[0]);
	      }
	    print("\r\nWriting New Reg Value.\r\n\r\nType c to continue edits, Or  q to quit. ");
		s =uartRead();
	} while( s != 'q' );
  print("\r\n\r\n");
  return;
}




