//top level module that instantiataes all sub-modules
module bs_wrapper(
clk,
rst,

//VGA control signals
v_sync,
blanking,

//pixel inputs
R,
G,
B,

//LED drivers
LED1_out,
LED2_out,

//Master signals
FSL_M_Full,
FSL_M_Write,
FSL_M_Clk,
FSL_M_Data,
FSL_M_Control,

//Slave Signals
FSL_S_Clk,
FSL_S_Exists,
FSL_S_Read,
FSL_S_Data,
FSL_S_Control
);

input clk;
input rst;
input int_ack;
input v_sync;
input blanking;
input [7:0] R,G,B;
output LED1_out;
output LED2_out;

//FIFO SLAVE INTERFACE
output FSL_S_Clk;
input [31:0] FSL_S_Data;
input FSL_S_Exists;
output FSL_S_Read;
input FSL_S_Control;

//FIFO MASTER INTERFACE
input FSL_M_Full;
output FSL_M_Write;
output [31:0] FSL_M_Data;
output FSL_M_Control;
output FSL_M_Clk;

reg [31:0] FSL_M_Data;
reg FSL_M_Write;
reg FSL_S_Read;

reg [23:0] thresh;
//output ad_15;
//output ad_30;
//output ad_45;
//output ad_60;

wire clk_27,bs_flag_in, LED1_wire, ad_15_wire, ad_30_wire, ad_45_wire, ad_60_wire;

wire ad_15_out;
wire ad_30_out;
wire ad_45_out;
wire ad_60_out;

assign FSL_M_Clk=clk_27;
assign FSL_S_Clk=clk_27;

//FIFO SLAVE LOGIC
always @(posedge clk_27)
begin
	if(FSL_S_Exists)
	thresh=FSL_S_Data[23:0];
end	

//FIFO reading
always @(posedge clk_27)
begin
	FSL_S_Read = 0;
	if(!FSL_S_Exists)
		FSL_S_Read = 0;
	else
		FSL_S_Read = 1;
end

//FIFO MASTER LOGIC
always @(posedge clk_27)
begin
	
	FSL_M_Write = 1;
	if(FSL_M_Full)
		FSL_M_Write = 0;
	else
		FSL_M_Write = 1;
end

//ad length flags
always @ (posedge clk_27)
begin
        if (rst )
			FSL_M_Data [31:0] <= {8'h00,24'h000000};
			else
			FSL_M_Data [31:0] <= {28'h0000000,!ad_15_out,!ad_30_out,!ad_45_out,!ad_60_out};
		  
end

//pulsegens for each of the 4 supported ad lengths

pulsegen PULSE15(
.clk (clk_27),
.rst (rst),
.signal_in (ad_15_wire),
.pulse_out(ad_15_out)
);

pulsegen PULSE30(
.clk (clk_27),
.rst (rst),
.signal_in (ad_30_wire),
.pulse_out(ad_30_out)
);

pulsegen PULSE45(
.clk (clk_27),
.rst (rst),
.signal_in (ad_45_wire),
.pulse_out(ad_45_out)
);

pulsegen PULSE60(
.clk (clk_27),
.rst (rst),
.signal_in (ad_60_wire),
.pulse_out(ad_60_out)
);

//single black screen detector
bs_detect DETECTOR(
.clk (clk_27),
.rst (rst),
.blanking_in (blanking),
.v_sync_in (v_sync),
.bs_flag_out(bs_flag_in),
.R_in(R),
.G_in(G),
.B_in(B),
.thresh(thresh)
);


//single ad detector
ad_detect AD_DECTECTOR(
.clk (clk_27),
.rst (rst),
.BS_found (bs_flag_in),
.LED2_pulse_15 (ad_15_wire),
.LED2_pulse_30 (ad_30_wire),
.LED2_pulse_45 (ad_45_wire),
.LED2_pulse_60 (ad_60_wire)
);


//LED pulse drivers
pulsegen PULSE1(
.clk (clk_27),
.rst (rst),
.signal_in (bs_flag_in),
.pulse_out(LED1_out)
);

pulsegen PULSE2(
.clk (clk_27),
.rst (rst),
.signal_in (ad_15_wire | ad_30_wire | ad_45_wire | ad_60_wire),
.pulse_out(LED2_out)
);


IBUFG CLKBUF (
.O (clk_27),
.I  (clk)
);

endmodule
