//     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
//     SOLELY FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR
//     XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION
//     AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE, APPLICATION
//     OR STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS
//     IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
//     AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
//     FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY
//     WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
//     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
//     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
//     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
//     FOR A PARTICULAR PURPOSE.
//
//     (c) Copyright 2005 Xilinx, Inc.
//     All rights reserved.
//
/*
-------------------------------------------------------------------------------
   Title      : VIDEO CAPTURE FROM THE VDEC1 DAUGHTER BOARD FOR THE XUP-V2Pro
   Project    : XUP-V2Pro
-------------------------------------------------------------------------------

   File       : VIDEO_CAPTURE.v
   Company    : Xilinx, Inc.
   Created    : 2004/07/22
   Last Update: 2005/06/15
   Copyright  : (c) Xilinx Inc, 2005
-------------------------------------------------------------------------------
    Uses       : lf_decode.v vp422_444_dup.v YCrCb2RGB.v LINE_BUFFER.v
                        NEG_EDGE_DETECT.v LINE_BUFFER.v SPECIAL_SVGA_TIMING_GENERATION.v
                                PIPE_LINE_DELAY.v

-------------------------------------------------------------------------------
   Used by    :
-------------------------------------------------------------------------------
   Description: This module captures 601/656 digital video data and displays the
                                video on a computer monitor.

        Conventions:
                All external port signals are UPPER CASE.
                All internal signals are LOWER CASE and are active HIGH.


-----------------------------------------------------------------------------
*/

module video_capture
(
YCrCb_in,
LLC_CLOCK,
PIXEL_CLOCK,
H_SYNC_Z,
V_SYNC_Z,
BLANK_Z,
COMP_SYNC,
R,
G,
B,
RESET_VDEC1_Z,
VDEC1_OE_Z,
VDEC1_PWRDN_Z,
system_dcm_locked,

//Master signals
FSL_M_Full,
FSL_M_Write,
FSL_M_Clk,
FSL_M_Data,
FSL_M_Control,

//Slave Signals
FSL_S_Clk,
FSL_S_Exists,
FSL_S_Read,
FSL_S_Data,
FSL_S_Control
//RESET_IN_Z,
//BYPASS_ONE_SHOT_Z,
//VDEC1_SDA,
//VDEC1_SCLK,
);


input [9:2] YCrCb_in;           // YCrCb digital video data from VDEC1 daughter board
input LLC_CLOCK;                        // Line Locked Clock (27MHz) from VDEC1 daughter board
output [7:0] R,G,B;                     // RGB video output to DAC
output PIXEL_CLOCK;							// pixel clock output to DAC                   
output H_SYNC_Z;                       // H SYNC output to SVGA connector
output V_SYNC_Z;                        // V SYNC output to SVGA connector
output BLANK_Z;                         // BLANK ouptut to DAC
output COMP_SYNC;                       // COMP SYNC output to DAC
output RESET_VDEC1_Z;           // RESET the video decoder on the VDEC1 daughter board
//output VDEC1_SDA;                     // I2C data output to the video decoder on the VDEC1 daughter board
//output VDEC1_SCLK;                    // I2C clock output to the video decoder on the VDEC1 daughter board
output VDEC1_OE_Z;                      // ENABLE the video decoder outputs on the VDEC1 daughter board
output VDEC1_PWRDN_Z;           // POWER DOWN the video decoder on the VDEC1 daughter board
//input RESET_IN_Z;                             // USER INPUT0 resets the video decoder
//input BYPASS_ONE_SHOT_Z;              // USER INPUT3 bypass the one shot to force vertical sync generation
input system_dcm_locked;        // reset from top level module


//FIFO SLAVE INTERFACE
output FSL_S_Clk;
input [31:0] FSL_S_Data;
input FSL_S_Exists;
output FSL_S_Read;
input FSL_S_Control;

//FIFO MASTER INTERFACE
input FSL_M_Full;
output FSL_M_Write;
output [31:0] FSL_M_Data;
output FSL_M_Control;
output FSL_M_Clk;




//wire RESET_IN_Z;
//wire BYPASS_ONE_SHOT_Z;


//wire VDEC1_SDA = 1'b1;
//wire VDEC1_SCLK = 1'b1;

wire RESET_VDEC1_Z = 1'b1;
wire VDEC1_OE_Z = 1'b0;
wire VDEC1_PWRDN_Z = 1'b1;

reg FSL_M_Write;
reg FSL_S_Read;
reg [31:0] FSL_M_Data;

reg [7:0] R;
reg [7:0] G;
reg [7:0] B;

reg [10:0] write_address;
reg read_enable_lb0;
reg write_enable_lb0;
reg crop;

wire PIXEL_CLOCK;
wire h_synch_delay;
wire v_synch_delay;
wire comp_synch;
wire blank;
wire rst;
wire [9:0] YCrCb_out_422;
wire Fo_422;
wire Vo_422;
wire Ho_422;
wire Fi_422;
wire Vi_422;
wire Hi_422;
wire Fo_444;
wire Vo_444;
wire Ho_444;
wire ceo_444;
wire  [9:0] YCrCb_in_422;
wire  [9:0] Y_out_444;
wire  [9:0] Cr_out_444;
wire  [9:0] Cb_out_444;
wire  [9:0] Y_in_444;
wire  [9:0] Cr_in_444;
wire  [9:0] Cb_in_444;
wire  [7:0] Red;
wire  [7:0] Green;
wire  [7:0] Blue;
wire H_SYNC_Z;
wire V_SYNC_Z;
wire BLANK_Z;
wire hsync;
wire vsync;
wire hblank;
wire llc_clock_i;
wire LLC_CLOCK;
wire clock_27;
wire clk_27;
wire clk_pixel;
wire clk_13;
wire clock_13;
wire clock_40;
wire clk_40;
wire system_dcm_rst;
wire system_dcm_locked;
wire low = 1'b0;
wire high = 1'b1;
wire [10:0] pixel_count;
wire read_enable_lb1 = !read_enable_lb0;
wire write_enable_lb1 = ! write_enable_lb0;
wire [7:0] write_red_data;
wire [7:0] write_green_data;
wire [7:0] write_blue_data;
wire [7:0] read_red_data_lb0;
wire [7:0] read_green_data_lb0;
wire [7:0] read_blue_data_lb0;
wire [7:0] read_red_data_lb1;
wire [7:0] read_green_data_lb1;
wire [7:0] read_blue_data_lb1;
wire one_shot_out;
wire reset_timing_gen;
wire [2:0] char_line_count;
wire [13:0] char_address;
wire [2:0] char_pixel;
wire hsync_in;
wire vsync_in;
wire blank_in;
wire comp_synch_in;
wire hsync_out;
wire vsync_out;
wire blank_out;
wire comp_synch_out;
wire NTSC_out;
wire  [9:0] concat_YCrCb_in;


assign Fi_422 = Fo_422;
assign Vi_422 = Vo_422;
assign Hi_422 = Ho_422;
assign YCrCb_in_422[9:0] = YCrCb_out_422[9:0];
assign  Y_in_444[9:0]  = Y_out_444[9:0];
assign  Cr_in_444[9:0]  = Cr_out_444[9:0];
assign  Cb_in_444[9:0]  = Cb_out_444[9:0];
assign H_SYNC_Z = hsync_out;
assign V_SYNC_Z = vsync_out;
assign BLANK_Z =  !blank_out;
//assign COMP_SYNC = !comp_synch_out;
assign COMP_SYNC = 1'b0; 	// disabled the sync on green
assign rst = !system_dcm_locked;
assign write_red_data[7:0] = Red[7:0];
assign write_green_data[7:0] = Green[7:0];
assign write_blue_data[7:0] = Blue[7:0];
assign reset_timing_gen = (rst | one_shot_out);
assign hsync_in = h_synch_delay;
assign vsync_in = v_synch_delay;
assign blank_in = blank;
assign comp_sync_in = comp_synch;
assign concat_YCrCb_in = {YCrCb_in[9:2],2'B00};

assign FSL_M_Clk=clk_27;
assign FSL_S_Clk=clk_27;

wire internal;

//FIFO SLAVE LOGIC
always @(posedge clk_27)
begin
	if(FSL_S_Exists)
		R = FSL_S_Data[31:24];
		G = FSL_S_Data[31:24];
		B = FSL_S_Data[31:24];
end	

//FIFO reading
always @(posedge clk_27)
begin
	FSL_S_Read = 0;
	if(!FSL_S_Exists)
		FSL_S_Read = 0;
	else
		FSL_S_Read = 1;
end


always @(posedge clk_27)
begin
	
	FSL_M_Write = 1;
	if(FSL_M_Full)
		FSL_M_Write = 0;
	else
		FSL_M_Write = 1;
end
	

// instantiate the clock input buffers for the line locked clock
IBUFG LLC_INPUT_BUF (
//.O  (llc_clock_i),	
.O (clk_27),
.I  (LLC_CLOCK)
);

// instantiate the clock input buffers for the internal clocks
BUFG CLK_13MHZ_BUF (
.O  (clk_13),
.I  (ceo_444)
);

// instantiate the clock input buffers for the internal clocks
BUFG CLK_PIXEL (
.O  (clk_pixel),
.I  (internal)
);

// instantiare a DDR output flip flop to center the clock in the pixel data
OFDDRRSE  internal_ff(
.Q   (internal),	
.C0  (clk_27),
.C1  (!clk_27),
.CE  (high),
.D0  (low),
.D1  (high),
.R   (reset),
.S   (low)
);

// instantiare a DDR output flip flop to center the clock in the pixel data
OFDDRRSE  PIXEL_CLOCK_DDR_FF(
.Q   (PIXEL_CLOCK),	
.C0  (clk_27),
.C1  (!clk_27),
.CE  (high),
.D0  (low),
.D1  (high),
.R   (reset),
.S   (low)
);

// INSTANTIATE THE LINE FIELD DECODER
// THIS EXTRACTS THE H,V,F BITS FROM THE
// TIMING REFERENCE CODES
lf_decode lf_decode_i(
.rst       (rst),                       // Reset and Clock input
.clk       (clk_27),                    // 27Mhz for SDTV
.YCrCb_in  (concat_YCrCb_in),           // data from the input video stream
.YCrCb_out (YCrCb_out_422),             // data delayed by pipe length
.NTSC_out  (NTSC_out),                  // high = NTSC format detected
.Fo        (Fo_422),                    // high = field one (even)
.Vo        (Vo_422),                    // high = vertical blank
.Ho        (Ho_422)                     // low = active video
);

// CONVERT FROM 4:2:2 DATA TO 4:4:4 DATA
vp422_444_dup vp422_444_dup_i(
.rst          (rst),                 // resets input data register and control
.clk          (clk_27),              // video component rate clock, 27Mhz for SDTV
.ycrcb_in     (YCrCb_in_422),        // video component data
.ntsc_in      (NTSC_out),     
.fi           (Fi_422),              // Low to High signals start of Field One
.vi           (Vi_422),              // High signals Vertical Blanking
.hi           (Hi_422),              // High signals Horizontal Blanking
.ceo          (ceo_444),             // output data rate is 1/2 the clock rate
.ntsc_out_o   (ntsc_out_o),   
.fo           (Fo_444),              // Field signal delayed by pipe length
.vo           (Vo_444),              // Vertical signal delayed by pipe length
.ho           (Ho_444),              // Horizontal signal delayed by pipe length
.y_out        (Y_out_444),           // Y out
.cr_out       (Cr_out_444),          // Cr out
.cb_out       (Cb_out_444)           // Cb out
);

// INSTANTIATE THE COLOR SPACE CONVERTER
YCrCb2RGB YCrCb2RGB_i(
.R    (Red),       
.G    (Green),     
.B    (Blue),      
.clk  (clk_13),    
.rst  (rst),       
.Y    (Y_in_444),  
.Cr   (Cr_in_444), 
.Cb   (Cb_in_444)  
);

// INSTANTIATE TWO VIDEO LINE BUFFERS. THESE LINE BUFFERS SWITCH
// FROM READ TO WRITE AT THE END OF EACH HORIZONTAL BLANKING INTERVAL

// toggle the line buffer on each Ho_444 (the start of the HBI)
always @ (posedge Ho_444 or posedge rst) begin
        if (rst) begin
                read_enable_lb0 <= 1'b0;
                write_enable_lb0 <= 1'b1;
                end
        else begin
                read_enable_lb0 <= !read_enable_lb0;
                write_enable_lb0 <= !write_enable_lb0;
                end
        end

        // create the write address counter
always @ (posedge clk_13 or posedge Ho_444) begin
        if (Ho_444) begin
                write_address <= 11'h000;
                end
           else begin
                write_address <= write_address + 1;
                end
        end

LINE_BUFFER LB0
(
.read_clk        (clk_27),
.read_address    (pixel_count),
.read_enable     (read_enable_lb0),
.read_red_data   (read_red_data_lb0),
.read_green_data (read_green_data_lb0),
.read_blue_data  (read_blue_data_lb0),

.write_clk        (clk_13),
.write_address    (write_address),
.write_enable     (write_enable_lb0),
.write_red_data   (write_red_data),
.write_green_data (write_green_data),
.write_blue_data  (write_blue_data)
);

LINE_BUFFER LB1
(
.read_clk         (clk_27),
.read_address     (pixel_count),
.read_enable      (read_enable_lb1),
.read_red_data    (read_red_data_lb1),
.read_green_data  (read_green_data_lb1),
.read_blue_data   (read_blue_data_lb1),

.write_clk        (clk_13),
.write_address    (write_address),
.write_enable     (write_enable_lb1),
.write_red_data   (write_red_data),
.write_green_data (write_green_data),
.write_blue_data  (write_blue_data)
);

// crop the first and last pixels of the line do to line count differences
always @ (posedge clk_27 or posedge rst) begin
        if (rst) begin
                crop <= 1'b1;
                end
        else if (pixel_count < 5) begin
                crop <= 1'b1;
                end
        else if (pixel_count > 714) begin
                crop <= 1'b1;
                end
        else begin
                crop <= 1'b0;
                end
        end

// create a mux for the line buffer outputs
always @ (posedge clk_27 or posedge rst) begin
        if (rst ) begin
                FSL_M_Data [31:0] <= {8'h00,24'h000000};
                //G[7:0] <= 8'h00;
                //B[7:0] <= 8'h00;
                end
        else if ( crop) begin
                FSL_M_Data [31:0] <= {8'h00,24'h000000};
                //G[7:0] <= 8'h00;
                //B[7:0] <= 8'h00;
                end
        else if (read_enable_lb0) begin
                FSL_M_Data [31:0] <= {read_red_data_lb0[7:0],24'h000000};
                //G[7:0] <= read_green_data_lb0[7:0];
                //B[7:0] <= read_blue_data_lb0[7:0];
                end
        else begin
                FSL_M_Data [31:0] <= {read_red_data_lb1[7:0],24'h000000};
                //G[7:0] <= read_green_data_lb1[7:0];
                //B[7:0] <= read_blue_data_lb1[7:0];
                end

        end

// INSTANTIATE A ONE SHOT TO DETECT THE FALLING EDGS OF THE FIELD
// BIT IN THE TIMING REFERENCE CODE. THIS PULSE RESETS THE
// SVGA TIMING GENERATION MODULE TO SYNCH THE OUTPUT VIDEO WITH
// THE VIDEO SOURCE
NEG_EDGE_DETECT NEG_EDGE_DETECT_i
(
.clk          (clk_27),     
.data_in      (Fo_444),     
.reset        (rst),        
.one_shot_out (one_shot_out)
);


// INSTANTIATE THE SVGA TIMING GENERATION MODULE
SPECIAL_SVGA_TIMING_GENERATION SPECIAL_SVGA_TIMING_GENERATION(
.pixel_clock          (clk_27),           
.reset                (reset_timing_gen), 
//.rst                //(rst),                      // remove the one shot for testing purposes
.h_synch_delay        (h_synch_delay),    
.v_synch_delay        (v_synch_delay),    
.comp_synch           (comp_synch),       
.blank                (blank),            
.char_line_count      (char_line_count),  
.char_address         (char_address),     
.char_pixel           (char_pixel),       
.pixel_count          (pixel_count)       
);

// align the syncs and blank with the video data
PIPE_LINE_DELAY PIPE_LINE_DELAY
(
.clk               (clk_27),       
.rst               (rst),          
.hsync_in          (hsync_in),     
.vsync_in          (vsync_in),     
.blank_in          (blank_in),     
.comp_sync_in      (comp_sync_in), 
.hsync_out         (hsync_out),    
.vsync_out         (vsync_out),    
.blank_out         (blank_out),    
.comp_sync_out     (comp_synch_out)
);

endmodule

module IBUFG(O, I); // synthesis syn_black_box
output O;
input I;
endmodule

module BUFG(O, I); // synthesis syn_black_box
output O;
input I;
endmodule


module OFDDRRSE (Q, C0, C1, CE, D0, D1, R, S); // synthesis syn_black_box
    output Q;
    input  C0, C1, CE, D0, D1, R, S;
endmodule
