module bs_detect(
clk,
rst,
blanking_in,
//h_sync_in,
v_sync_in,
bs_flag_out,
R_in,
G_in,
B_in

);

output bs_flag_out;
input clk;            //pixel clock
input rst;           //rest (if neccessary)
input blanking_in;   //blanking from the SVGA timing
//input h_sync_in;     //h_sync from SVGA timing
input v_sync_in;     //v_sync from SVGA timing
input [7:0]R_in;     //R, G, B from LFBUFS
input [7:0]G_in;
input [7:0]B_in;
   //indicates if output frame is black screen


reg [2:0] presentState, nextState;

reg bs_flag;
reg reset_counter;
reg enable_counter;
reg not_blsc;

assign bs_flag_out=bs_flag;

parameter [2:0] reset = 3'b000;
parameter [2:0] low_V = 3'b001;
parameter [2:0] wait_BL = 3'b010;
parameter [2:0] count = 3'b011;
parameter [2:0] not_bs = 3'b100;
parameter [2:0] wait_V = 3'b101;
parameter [2:0] bs_found = 3'b110;

//next state and control logic
always@(v_sync_in or blanking_in or not_blsc)
begin
    reset_counter=0;
    enable_counter=0;
    bs_flag=0;
    case(presentState)
        reset:begin
                 reset_counter=1;
                 if(v_sync_in)   nextState=reset;
                 else            nextState=low_V;
              end
        low_V:begin
               reset_counter=1;
               if(!v_sync_in)   nextState=low_V;
               else             nextState=wait_BL;
           end
        wait_BL:begin
                   reset_counter=0;
                   if(blanking_in) nextState=wait_BL;
                   else            nextState=count;
               end
                
        count:begin
               enable_counter=1;
                  if((not_blsc && !blanking_in) || (not_blsc && blanking_in))      
                     nextState=not_bs;
                 else if(blanking_in)   
                    nextState=wait_V;
                 else              
                    nextState=count;
              end        
        wait_V:begin
               enable_counter=0;
               if(blanking_in && v_sync_in)   
               nextState=wait_V;
               else if(!blanking_in)           
                  nextState=count;
               else if(blanking_in && !v_sync_in)
                  nextState=bs_found;
              end
               
        not_bs:begin
                  enable_counter=0;
                 if(v_sync_in)                  nextState=not_bs;
                 else                          nextState=low_V;
               end
                 
       bs_found:begin
              reset_counter=1;
              bs_flag=1;
              if(v_sync_in)   nextState=wait_BL;
              else            nextState=low_V;
           end
        default: nextState=reset;
   endcase
end

always@(posedge clk or posedge rst)
begin
      if(rst)
         presentState <=reset;
       else
          presentState <= nextState; 
end

reg [63:0]Rcounter;
reg [63:0]Gcounter;
reg [63:0]Bcounter;

//saturating adder
always@(posedge clk)
begin
    if(reset_counter)begin
       Rcounter=64'h00000000;
       Gcounter=64'h00000000;
       Bcounter=64'h00000000;
   end
    else if(enable_counter)begin
       Rcounter=Rcounter+R_in;
       Gcounter=Gcounter+G_in;
       Bcounter=Bcounter+B_in;
   end
       
end

parameter [63:0] threshold=64'h0000000f;
//parameter [63:0] threshold = 64'h00003660;

//checks for black screen
always@(Rcounter or Gcounter or Bcounter)
begin
    if((Rcounter+(2*Gcounter)+Bcounter)/4 > threshold)
       not_blsc=1;
    else
        not_blsc=0;
end

endmodule